==> friend-0.2.0.tar.gz: friend-0.2.0/tests/friend/test_collections.py <==
# Copyright 2017 Joseph Wright <joseph@cloudboss.co>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
import unittest

from friend import collections


class CollectionsTests(unittest.TestCase):
    def test_select_dict(self):
        dicts = [
            {'a': 'A', 'b': 'B', 'c': 'C'},
            {'one': 'won'},
            {'one': 1, 'two': 2},
        ]
        expectations = (
            (
                'one',
                'won',
                [{'one': 'won'}]
            ),
            (
                'one',
                ('won', 1),
                [{'one': 'won'}, {'one': 1, 'two': 2}]
            ),
            (
                'one',
                (2, 'won'),
                [{'one': 'won'}]
            ),
            (
                2,
                0,
                []
            ),
            (
                'a',
                'B',
                []
            ),
            (
                'a',
                'A',
                [{'a': 'A', 'b': 'B', 'c': 'C'}]
            ),
            (
                0,
                (),
                []
            )
        )
        for key, value, d in expectations:
            self.assertEquals(collections.select_dict(dicts, key, value), d)

==> friend-0.2.1.tar.gz: friend-0.2.1/tests/friend/test_collections.py <==
# Copyright 2018 Joseph Wright <joseph@cloudboss.co>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
import unittest

from friend import collections


class CollectionsTests(unittest.TestCase):
    def test_select_dict(self):
        dicts = [
            {'a': 'A', 'b': 'B', 'c': 'C'},
            {'one': 'won'},
            {'one': '1', 'two': '2'},
        ]
        expectations = (
            (
                'one',
                'won',
                [{'one': 'won'}]
            ),
            (
                'one',
                ('won', '1'),
                [{'one': 'won'}, {'one': '1', 'two': '2'}]
            ),
            (
                'one',
                (2, 'won'),
                [{'one': 'won'}]
            ),
            (
                2,
                0,
                []
            ),
            (
                'a',
                'B',
                []
            ),
            (
                'a',
                'A',
                [{'a': 'A', 'b': 'B', 'c': 'C'}]
            ),
            (
                0,
                (),
                []
            )
        )
        for key, value, d in expectations:
            self.assertEqual(collections.select_dict(dicts, key, value), d)
